pub struct MarkingCache { /* private fields */ }Expand description
Cache of computed state snapshots for efficient seek/step operations.
Implementations
Sourceimpl MarkingCache
impl MarkingCache
Sourcepub fn compute_at(
&mut self,
events: &[NetEvent],
target_index: usize,
) -> ComputedState
pub fn compute_at( &mut self, events: &[NetEvent], target_index: usize, ) -> ComputedState
Computes the state at the given event index, using cached snapshots to minimize the number of events that need to be replayed.
Sourcepub fn invalidate(&mut self)
pub fn invalidate(&mut self)
Invalidates the cache.